This directory stores all wrapper files associated with the suite.

If you have a new model that you would like to add to the suite, you can do so by implementing the custom model wrapper file in this directory.

If you have a new drug response dataset on which you would like to test our models, you can add it by implementing the custom data wrapper file in this directory.
